@@ -23,7 +23,7 @@
    char *getenv();
 #endif
 #if defined (__linux__)
-#  include <termcap.h>
+#  include <ncurses/termcap.h>
 #else
   char *tgetstr(), *tgoto();
   int tgetent(), tputs(), tgetnum(), tgetflag();
